%define major   3.4

Name:           yum
Version:        3.4.3
Release:        %mkrel 19
Summary:        RPM installer/updater
License:        GPLv2+
Group:          System/Packaging
Source:         http://yum.baseurl.org/download/%{major}/%{name}-%{version}.tar.gz
Patch1:         yum-geode-arch.patch
Patch2:         yum-HEAD.patch
Patch3:         yum-ppc64-preferred.patch
Patch4:         yum-completion-helper.patch
# Add yum-deprecated patch from Fedora to ensure
# that it won't conflict with dnf-yum's /usr/bin/yum.
# Mock and other tools using it already handle the
# rename of yum to yum-deprecated. (ngompa)
Patch10:        yum-deprecated.patch
URL:            http://yum.baseurl.org/
Requires:	python-yum = %{version}-%{release}
BuildRequires:  python-devel
BuildRequires:	gettext
BuildRequires:  intltool
BuildRequires:  bash-completion
BuildRequires:  systemd-devel
BuildArch:      noarch
Requires:       bash-completion

%description
Yum is a utility that can check for and automatically download and
install updated RPM packages. Dependencies are obtained and downloaded
automatically prompting the user as necessary.

%package -n python-%{name}
Summary:	Reusable YUM code
Group:		Development/Python
Requires:       python-celementtree
Requires:       python-gpgme
Requires:       python-iniparse
Requires:       python-libxml2
Requires:       python-rpm
Requires:       python-urlgrabber
Requires:       python-lzma
Requires:       yum-metadata-parser
Conflicts:      yum < 3.2.29-2
%description -n python-%{name}
YUM code that is also used in other tools like createrepo.

%prep
%setup -q
%autopatch -p1

%build
%make_build

%install
%make_install INIT=systemd UNITDIR=%{_unitdir}

# correct scripts
perl -pi -e 's|%{_libdir}/yum|%{_datadir}/yum|' %{buildroot}%{_bindir}/*

# remove init stuff
rm -rf %{buildroot}%{_unitdir}
rm -rf %{buildroot}%{_sysconfdir}/cron.*
rm -rf %{buildroot}%{_sysconfdir}/init.d/
rm -rf %{buildroot}%{_sysconfdir}/rc.d/
rm -rf %{buildroot}%{_sysconfdir}/logrotate.d
rm -Rf  %{buildroot}%{python2_sitelib}/urlgrabber/

# Fix bash completion files
rm %{buildroot}%{_datadir}/bash-completion/completions/yummain.py


%find_lang %{name}

%files -f %{name}.lang
%doc README AUTHORS TODO INSTALL
%license COPYING
%config(noreplace) %{_sysconfdir}/yum/
%{_datadir}/yum-cli/
%{_bindir}/*
%{_sbindir}/*
%{_localstatedir}/cache/yum
%{_datadir}/bash-completion/completions/yum
%{_mandir}/man*/*
%attr(0644,root,root) %{_sysconfdir}/dbus-1/system.d/yum-updatesd.conf

%files -n python-%{name}
%{python2_sitelib}/%{name}
%{python2_sitelib}/rpmUtils


%changelog
* Sat May 06 2017 ngompa <ngompa> 3.4.3-19.mga6
+ Revision: 1099345
- Sync patches from Fedora
- Add support for Recommends
- Remove leftover unused init stuff

* Sat Dec 17 2016 ngompa <ngompa> 3.4.3-18.mga6
+ Revision: 1075803
- Add missing pyliblzma dep for processing xz compressed repodata

* Tue Mar 15 2016 ngompa <ngompa> 3.4.3-17.mga6
+ Revision: 991075
- Fix license tag and bash completion path

* Tue Mar 15 2016 daviddavid <daviddavid> 3.4.3-16.mga6
+ Revision: 991026
- rediff yum-deprecated patch (since fixed autopatch)

* Sat Feb 20 2016 umeabot <umeabot> 3.4.3-15.mga6
+ Revision: 972082
- Mageia 6 Mass Rebuild

* Sun Oct 25 2015 ngompa <ngompa> 3.4.3-14.mga6
+ Revision: 895419
- Apply yum-deprecated patch from Fedora

* Wed Oct 15 2014 umeabot <umeabot> 3.4.3-13.mga5
+ Revision: 743800
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.4.3-12.mga5
+ Revision: 730750
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.4.3-11.mga5
+ Revision: 690848
- Mageia 5 Mass Rebuild

  + pterjan <pterjan>
    - Rebuild for new Python

* Sun Feb 09 2014 bcornec <bcornec> 3.4.3-9.mga5
+ Revision: 586901
- Force update with new tag to have a correct Group info as the current version doesn't build

* Sat Oct 19 2013 umeabot <umeabot> 3.4.3-8.mga5
+ Revision: 536157
- Mageia 4 Mass Rebuild

* Sun Sep 22 2013 tv <tv> 3.4.3-7.mga4
+ Revision: 483454
- rebuild for new rpm

* Tue Jan 22 2013 fwang <fwang> 3.4.3-6.mga3
+ Revision: 390826
- update rpm group

* Mon Jan 14 2013 umeabot <umeabot> 3.4.3-5.mga3
+ Revision: 387638
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Apr 29 2012 colin <colin> 3.4.3-4.mga2
+ Revision: 234193
- Add LSB headers to initscripts (mga#5262)

* Mon Jul 04 2011 misc <misc> 3.4.3-3.mga2
+ Revision: 118315
- fix conflict ( spotted by spturtle on irc )

* Mon Jul 04 2011 misc <misc> 3.4.3-2.mga2
+ Revision: 118311
- add conflict to fix upgrade from older version

* Sat Jul 02 2011 kharec <kharec> 3.4.3-1.mga2
+ Revision: 117371
- update to 3.4.3

* Mon Jun 27 2011 kharec <kharec> 3.4.2-1.mga2
+ Revision: 114370
- new version

* Tue Jun 21 2011 kharec <kharec> 3.4.1-1.mga2
+ Revision: 111692
- update to new version and update major too

  + cjw <cjw>
    - fix URL

* Thu Jun 09 2011 cjw <cjw> 3.2.29-2.mga2
+ Revision: 102597
- split package so yum does not need to be installed to run createrepo

* Wed Apr 13 2011 tv <tv> 3.2.29-1.mga1
+ Revision: 84627
- new release

* Sun Jan 09 2011 kharec <kharec> 3.2.28-2.mga1
+ Revision: 1450
- imported package yum

